# jQuery UI Fold Effect

## Overview

Folds the element like a piece of paper.

### Dependencies

- Effects Core

### Example

- Demo
- View Source

Hides the element by folding it first to 15px, then completely.

    $("div").click(function () {
          $(this).hide("fold", {}, 1000);
    });

    <!DOCTYPE html>
    <html>
    <head>
      <link href="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/themes/base/jquery-ui.css" rel="stylesheet" type="text/css"/>
      <script src="http://ajax.googleapis.com/ajax/libs/jquery/1.4/jquery.min.js"></script>
      <script src="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/jquery-ui.min.js"></script>

    <script src="http://jqueryui.com/latest/ui/effects.core.js"></script>
    <script src="http://jqueryui.com/latest/ui/effects.fold.js"></script>
    <style type="text/css">
      div { margin: 0px; width: 100px; height: 80px; background: green; border: 1px solid black; position: relative; }
    </style>

      <script>
      $(document).ready(function() {

    $("div").click(function () {
          $(this).hide("fold", {}, 1000);
    });

      });
      </script>
    </head>
    <body style="font-size:62.5%;">
      <div></div>
    </body>
    </html>

## Arguments

- ### horizFirst

  Type:
    Boolean
  Default:
    false

  Whether to fold horizontally first or not. Can be true or false.

- ### mode

  Type:
    String
  Default:
    "hide"

  The mode of the effect. Can be "show" or "hide".

- ### size

  Type:
    Integer
  Default:
    15

  Size to be folded to.